@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procsignal.h,v 1.16 1999/02/23 11:43:10 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -44,11 +42,11 @@ typedef struct _glibtop_proc_signal	glibtop_proc_signal;
 
 struct _glibtop_proc_signal
 {
-    u_int64_t	flags,
-	signal [2],		/* mask of pending signals */
-	blocked [2],		/* mask of blocked signals */
-	sigignore [2],		/* mask of ignored signals */
-	sigcatch [2];		/* mask of caught  signals */
+	u_int64_t	flags,
+		signal [2],		/* mask of pending signals */
+		blocked [2],		/* mask of blocked signals */
+		sigignore [2],		/* mask of ignored signals */
+		sigcatch [2];		/* mask of caught  signals */
 };
 
 #define glibtop_get_proc_signal(p1, p2)	glibtop_get_proc_signal_l(glibtop_global_server, p1, p2)
@@ -59,14 +57,14 @@ struct _glibtop_proc_signal
 #define glibtop_get_proc_signal_r	glibtop_get_proc_signal_s
 #endif
 
-int glibtop_get_proc_signal_l (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
+void glibtop_get_proc_signal_l (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_SIGNAL
-int glibtop_init_proc_signal_p (glibtop *server);
-int glibtop_get_proc_signal_p (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
+void glibtop_init_proc_signal_p (glibtop *server);
+void glibtop_get_proc_signal_p (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
 #else
-int glibtop_init_proc_signal_s (glibtop *server);
-int glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
+void glibtop_init_proc_signal_s (glibtop *server);
+void glibtop_get_proc_signal_s (glibtop *server, glibtop_proc_signal *buf, pid_t pid);
 #endif
 
 #ifdef GLIBTOP_NAMES
