@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: swap.c,v 1.4 1999/05/03 12:20:21 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -38,21 +36,19 @@ static const unsigned long _glibtop_sysdeps_swap =
 
 /* Init function. */
 
-int
+void
 glibtop_init_swap_s (glibtop *server)
 {
     server->sysdeps.swap = _glibtop_sysdeps_swap;
-
-    return 0;
 }
 
 /* Provides information about swap usage. */
 
-int
+void
 glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 {
-    kstat_ctl_t *kc = server->_priv->machine.kc;
-    kstat_t *ksp = server->_priv->machine.vminfo_kstat;
+    kstat_ctl_t *kc = server->machine.kc;
+    kstat_t *ksp = server->machine.vminfo_kstat;
     u_int64_t swap_resv, swap_alloc, swap_avail, swap_free;
     vminfo_t vminfo;
     double rate;
@@ -60,37 +56,34 @@ glibtop_get_swap_s (glibtop *server, glibtop_swap *buf)
 
     memset (buf, 0, sizeof (glibtop_swap));
 
-    if (!ksp)
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
+    if (!ksp) return;
 
     switch(kstat_chain_update(kc))
-	{
+    {
         case -1: assert(0); /* Debugging, shouldn't happen */
 	case 0:  break;
 	default: glibtop_get_kstats(server);
-	}
+    }
     ret = kstat_read (kc, ksp, &vminfo);
 
     if (ret == -1) {
 	glibtop_warn_io_r (server, "kstat_read (vminfo)");
-	return -GLIBTOP_ERROR_INCOMPATIBLE_KERNEL;
+	return;
     }
 
-    rate = (ksp->ks_snaptime - server->_priv->machine.vminfo_snaptime) / 1E+9;
+    rate = (ksp->ks_snaptime - server->machine.vminfo_snaptime) / 1E+9;
 
-    swap_resv = (vminfo.swap_resv - server->_priv->machine.vminfo.swap_resv) / rate;
-    swap_alloc = (vminfo.swap_alloc - server->_priv->machine.vminfo.swap_alloc) / rate;
-    swap_avail = (vminfo.swap_avail - server->_priv->machine.vminfo.swap_avail) / rate;
-    swap_free = (vminfo.swap_free - server->_priv->machine.vminfo.swap_free) / rate;
+    swap_resv = (vminfo.swap_resv - server->machine.vminfo.swap_resv) / rate;
+    swap_alloc = (vminfo.swap_alloc - server->machine.vminfo.swap_alloc) / rate;
+    swap_avail = (vminfo.swap_avail - server->machine.vminfo.swap_avail) / rate;
+    swap_free = (vminfo.swap_free - server->machine.vminfo.swap_free) / rate;
 
-    memcpy (&server->_priv->machine.vminfo, &vminfo, sizeof (vminfo_t));
-    server->_priv->machine.vminfo_snaptime = ksp->ks_snaptime;
+    memcpy (&server->machine.vminfo, &vminfo, sizeof (vminfo_t));
+    server->machine.vminfo_snaptime = ksp->ks_snaptime;
 
     buf->total = swap_resv + swap_avail;
     buf->used = swap_alloc;
     buf->free = buf->total - buf->used;
 
     buf->flags = _glibtop_sysdeps_swap;
-
-    return 0;
 }
