@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proctime.c,v 1.6 1999/02/23 11:46:32 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,21 +28,17 @@ static const unsigned long _glibtop_sysdeps_proc_time = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_time_s (glibtop *server)
 {
-    server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
-
-    return 0;
+	server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_time_s (glibtop *server, glibtop_proc_time *buf,
 			 pid_t pid)
 {
-    memset (buf, 0, sizeof (glibtop_proc_time));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_proc_time));
 }
